@@ -6,8 +6,10 @@ except:
     web = ximport("__init__")
     reload(web)
 
-q = "Finland"
-article = web.wikipedia.search(q, language="fi")
+web.clear_cache()
+
+q = "computer graphics"
+article = web.wikipedia.search(q, language="en")
 
 # Get the article title.
 text(article.title, 20, 40)
